@@ -4,8 +4,8 @@ use warnings;
 use 5.010;
 
 # core modules since 5.014
-require HTTP::Tiny;
-require JSON::PP;
+use HTTP::Tiny;
+use JSON::PP;
 
 use Pandoc;
 use Pandoc::Version;
@@ -15,14 +15,16 @@ use File::Copy 'move';
 
 =head1 NAME
 
-Pandoc::Release - information about pandoc releases from GitHub
+Pandoc::Release - get pandoc releases from GitHub
 
 =cut
 
-our $VERSION = '0.7.0';
+our $VERSION = '0.7.1';
 
 sub list {
-	my ($class, %opts) = @_;
+    my ($class, %opts) = @_;
+
+    my $range = $opts{range};
     my $since = Pandoc::Version->new($opts{since} // 0);
 	my $client = HTTP::Tiny->new();
     my $url = "https://api.github.com/repos/jgm/pandoc/releases";
@@ -33,8 +35,12 @@ sub list {
         my $res = $client->get($url);
         $res->{success} or die "failed to fetch $url";
         foreach (@{ JSON::PP::decode_json($res->{content}) }) {
-            last LOOP unless $since < $_->{tag_name};
-            push @releases, bless $_, $class;
+            my $version = Pandoc::Version->new($_->{tag_name});
+            last LOOP unless $since < $version; # abort if possible
+            if (!$range || $version->fulfills($range)) {
+                push @releases, bless $_, $class;
+                last LOOP if $range and $range =~ /^==v?(\d+(\.\d)*)$/;
+            }
         }
 
         my $link = $res->{headers}{link} // '';
@@ -57,7 +63,7 @@ sub download {
 	-d $dir or die "missing directory $dir";
     if ($bin) {
         make_path($bin);
-		-d $bin or die "missing directory $bin"; 
+		-d $bin or die "missing directory $bin";
     }
 
     my ($asset) = grep { $_->{name} =~ /-$arch\.deb$/ } @{$self->{assets}};
@@ -102,25 +108,24 @@ __END__
 This utility module fetches information about pandoc releases via GitHub API.
 It requires at least Perl 5.14 or L<HTTP::Tiny> and L<JSON::PP> installed.
 
-=head1 FUNCTIONS
-
-=head2 list( [ since => $version ] [, verbose => 0|1 ] )
-
-Get a list of all releases, optionally since a given pandoc version. Option
-C<verbose> will print URLs before each request.
-
 =head1 METHODS
 
+=head2 list( [ since => $version ] [ range => $range ] [, verbose => 0|1 ] )
+
+Get a list of all pandoc releases at GitHub, optionally since some version and
+within a version range such as C<!=1.16, <=1.17> or C<==2.1.2>. See
+L<CPAN::Meta::Spec/Version Ranges> for possible values. Option C<verbose> will
+print URLs before each request.
+
 =head2 download( arch => $arch, dir => $dir [, bin => $bin] [, verbose => 0|1] )
 
 Download the Debian release file for some architecture (e.g. C<amd64>) to
-directory C<dir>, unless already there. Optionally extract pandoc binary to
-C<bin> directory named after version number (e.g. C<bin/2.1.2>). The binary can
-then be wrapped as instance of L<Pandoc>:
+directory C<dir>, unless already there. Optionally extract pandoc executables
+to directory C<bin>, each named by pandoc version number (e.g. C<2.1.2>).
+These executables can be used with constructor of L<Pandoc> and with
+L<App::Prove::Plugin::andoc>:
 
-  my $pandoc = Pandoc->new("$dir/$version");
-
-Returns the version number as L<Pandoc::Version> on success.
+  my $pandoc = Pandoc->new("$bin/$version");
 
 =head1 SEE ALSO
 
